//go:build !5BytesOffset
// +build !5BytesOffset

package util

const (
	SizeLimit         = "30GB"
	VolumeSizeLimitGB = 30
)
